@@ -10,7 +10,7 @@ import (
 )
 
 type HTTPGroupController struct {
-	// groups by indexKey
+	// groups indexed by group name
 	groups map[string]*HTTPGroup
 
 	// register createConn for each group to vhostRouter.
@@ -31,7 +31,6 @@ func (ctl *HTTPGroupController) Register(
 	proxyName, group, groupKey string,
 	routeConfig vhost.RouteConfig,
 ) (err error) {
-
 	indexKey := group
 	ctl.mu.Lock()
 	g, ok := ctl.groups[indexKey]
@@ -66,7 +65,7 @@ type HTTPGroup struct {
 	location        string
 	routeByHTTPUser string
 
-	// CreateConnFuncs indexed by echo proxy name
+	// CreateConnFuncs indexed by proxy name
 	createFuncs map[string]vhost.CreateConnFunc
 	pxyNames    []string
 	index       uint64
@@ -86,13 +85,14 @@ func (g *HTTPGroup) Register(
 	proxyName, group, groupKey string,
 	routeConfig vhost.RouteConfig,
 ) (err error) {
-
 	g.mu.Lock()
 	defer g.mu.Unlock()
 	if len(g.createFuncs) == 0 {
 		// the first proxy in this group
 		tmp := routeConfig // copy object
 		tmp.CreateConnFn = g.createConn
+		tmp.ChooseEndpointFn = g.chooseEndpoint
+		tmp.CreateConnByEndpointFn = g.createConnByEndpoint
 		err = g.ctl.vhostRouter.Add(routeConfig.Domain, routeConfig.Location, routeConfig.RouteByHTTPUser, &tmp)
 		if err != nil {
 			return
@@ -152,7 +152,7 @@ func (g *HTTPGroup) createConn(remoteAddr string) (net.Conn, error) {
 	routeByHTTPUser := g.routeByHTTPUser
 	if len(g.pxyNames) > 0 {
 		name := g.pxyNames[int(newIndex)%len(g.pxyNames)]
-		f, _ = g.createFuncs[name]
+		f = g.createFuncs[name]
 	}
 	g.mu.RUnlock()
 
@@ -163,3 +163,36 @@ func (g *HTTPGroup) createConn(remoteAddr string) (net.Conn, error) {
 
 	return f(remoteAddr)
 }
+
+func (g *HTTPGroup) chooseEndpoint() (string, error) {
+	newIndex := atomic.AddUint64(&g.index, 1)
+	name := ""
+
+	g.mu.RLock()
+	group := g.group
+	domain := g.domain
+	location := g.location
+	routeByHTTPUser := g.routeByHTTPUser
+	if len(g.pxyNames) > 0 {
+		name = g.pxyNames[int(newIndex)%len(g.pxyNames)]
+	}
+	g.mu.RUnlock()
+
+	if name == "" {
+		return "", fmt.Errorf("no healthy endpoint for http group [%s], domain [%s], location [%s], routeByHTTPUser [%s]",
+			group, domain, location, routeByHTTPUser)
+	}
+	return name, nil
+}
+
+func (g *HTTPGroup) createConnByEndpoint(endpoint, remoteAddr string) (net.Conn, error) {
+	var f vhost.CreateConnFunc
+	g.mu.RLock()
+	f = g.createFuncs[endpoint]
+	g.mu.RUnlock()
+
+	if f == nil {
+		return nil, fmt.Errorf("no CreateConnFunc for endpoint [%s] in group [%s]", endpoint, g.group)
+	}
+	return f(remoteAddr)
+}
